from .snappicommon import SnappiList


class CaptureBasicFilterList(SnappiList):
    def __init__(self):
        super(CaptureBasicFilterList, self).__init__()


    def capturebasicfilter(self, and_operator=True, not_operator=False):
        from .capturebasicfilter import CaptureBasicFilter
        item = CaptureBasicFilter(and_operator, not_operator)
        self._add(item)
        return self

    def mac_address(self, mac='None', filter=None, mask=None):
        from .capturebasicfilter import CaptureBasicFilter
        item = CaptureBasicFilter()
        item.mac_address
        self._add(item)
        return self

    def custom(self, filter=None, mask=None, offset=None):
        from .capturebasicfilter import CaptureBasicFilter
        item = CaptureBasicFilter()
        item.custom
        self._add(item)
        return self



from .snappicommon import SnappiList


class CaptureList(SnappiList):
    def __init__(self):
        super(CaptureList, self).__init__()


    def capture(self, name=None, port_names=None, pcap=None, enable=True, overwrite=False, format='pcap'):
        from .capture import Capture
        item = Capture(name, port_names, pcap, enable, overwrite, format)
        self._add(item)
        return self



from .snappicommon import SnappiObject


class Config(SnappiObject):
    _TYPES = {
        'ports': '.portlist.PortList',
        'lags': '.laglist.LagList',
        'layer1': '.layer1list.Layer1List',
        'captures': '.capturelist.CaptureList',
        'devices': '.devicelist.DeviceList',
        'flows': '.flowlist.FlowList',
        'options': '.configoptions.ConfigOptions',
    }

    def __init__(self):
        super(Config, self).__init__()

    @property
    def ports(self):
        """ports getter

        The ports that will be configured on the traffic generator.

        Returns: list[obj(snappi.Port)]
        """
        from .portlist import PortList
        if 'ports' not in self._properties or self._properties['ports'] is None:
            self._properties['ports'] = PortList()
        return self._properties['ports']

    @property
    def lags(self):
        """lags getter

        The lags that will be configured on the traffic generator.

        Returns: list[obj(snappi.Lag)]
        """
        from .laglist import LagList
        if 'lags' not in self._properties or self._properties['lags'] is None:
            self._properties['lags'] = LagList()
        return self._properties['lags']

    @property
    def layer1(self):
        """layer1 getter

        The layer1 settings that will be configured on the traffic generator.

        Returns: list[obj(snappi.Layer1)]
        """
        from .layer1list import Layer1List
        if 'layer1' not in self._properties or self._properties['layer1'] is None:
            self._properties['layer1'] = Layer1List()
        return self._properties['layer1']

    @property
    def captures(self):
        """captures getter

        The capture settings that will be configured on the traffic generator.

        Returns: list[obj(snappi.Capture)]
        """
        from .capturelist import CaptureList
        if 'captures' not in self._properties or self._properties['captures'] is None:
            self._properties['captures'] = CaptureList()
        return self._properties['captures']

    @property
    def devices(self):
        """devices getter

        The emulated device settings that will be configured on the traffic generator.

        Returns: list[obj(snappi.Device)]
        """
        from .devicelist import DeviceList
        if 'devices' not in self._properties or self._properties['devices'] is None:
            self._properties['devices'] = DeviceList()
        return self._properties['devices']

    @property
    def flows(self):
        """flows getter

        The flows that will be configured on the traffic generator.

        Returns: list[obj(snappi.Flow)]
        """
        from .flowlist import FlowList
        if 'flows' not in self._properties or self._properties['flows'] is None:
            self._properties['flows'] = FlowList()
        return self._properties['flows']

    @property
    def options(self):
        """options getter

        TBD

        Returns: obj(snappi.ConfigOptions)
        """
        from .configoptions import ConfigOptions
        if 'options' not in self._properties or self._properties['options'] is None:
            self._properties['options'] = ConfigOptions()
        return self._properties['options']



from .snappicommon import SnappiList


class DeviceBgpv4RouteRangeList(SnappiList):
    def __init__(self):
        super(DeviceBgpv4RouteRangeList, self).__init__()


    def devicebgpv4routerange(self, name=None, route_count_per_device=1):
        from .devicebgpv4routerange import DeviceBgpv4RouteRange
        item = DeviceBgpv4RouteRange(name, route_count_per_device)
        self._add(item)
        return self



import pytest


def test_snappi_list_serialization(api):
    """Test serialization and deserialization of Snappi list objects
    """
    port_metrics1 = api.port_metrics().portmetric().portmetric()
    serialization = port_metrics1.serialize()
    port_metrics2 = api.port_metrics()
    port_metrics2.deserialize(serialization)
    print(port_metrics2)
    

if __name__ == '__main__':
    pytest.main(['-vv', '-s', __file__])



from .snappicommon import SnappiList


class PortStateList(SnappiList):
    def __init__(self):
        super(PortStateList, self).__init__()


    def portstate(self, name=None, link='None', capture='None'):
        from .portstate import PortState
        item = PortState(name, link, capture)
        self._add(item)
        return self



from .snappicommon import SnappiList


class FlowBitPatternList(SnappiList):
    def __init__(self):
        super(FlowBitPatternList, self).__init__()


    def flowbitpattern(self):
        from .flowbitpattern import FlowBitPattern
        item = FlowBitPattern()
        self._add(item)
        return self

    def bitlist(self, offset=1, length=1, count=1, values=None):
        from .flowbitpattern import FlowBitPattern
        item = FlowBitPattern()
        item.bitlist
        self._add(item)
        return self

    def bitcounter(self, offset=0, length=32, count=1, start=0, step=0):
        from .flowbitpattern import FlowBitPattern
        item = FlowBitPattern()
        item.bitcounter
        self._add(item)
        return self



from .snappicommon import SnappiList


class FlowList(SnappiList):
    def __init__(self):
        super(FlowList, self).__init__()


    def flow(self, name=None):
        from .flow import Flow
        item = Flow(name)
        self._add(item)
        return self



from .snappicommon import SnappiObject


class Layer1FlowControl(SnappiObject):
    _TYPES = {
        'ieee_802_1qbb': '.layer1ieee8021qbb.Layer1Ieee8021qbb',
        'ieee_802_3x': '.layer1ieee8023x.Layer1Ieee8023x',
    }

    def __init__(self, directed_address=None):
        super(Layer1FlowControl, self).__init__()
        self.directed_address = directed_address

    @property
    def ieee_802_1qbb(self):
        from .layer1ieee8021qbb import Layer1Ieee8021qbb
        if 'ieee_802_1qbb' not in self._properties or self._properties['ieee_802_1qbb'] is None:
            self._properties['ieee_802_1qbb'] = Layer1Ieee8021qbb()
        self.choice = 'ieee_802_1qbb'
        return self._properties['ieee_802_1qbb']

    @property
    def ieee_802_3x(self):
        from .layer1ieee8023x import Layer1Ieee8023x
        if 'ieee_802_3x' not in self._properties or self._properties['ieee_802_3x'] is None:
            self._properties['ieee_802_3x'] = Layer1Ieee8023x()
        self.choice = 'ieee_802_3x'
        return self._properties['ieee_802_3x']

    @property
    def directed_address(self):
        """directed_address getter

        The 48bit mac address that the layer1 port names will listen on for a directed pause. 

        Returns: str
        """
        return self._properties['directed_address']

    @directed_address.setter
    def directed_address(self, value):
        """directed_address setter

        The 48bit mac address that the layer1 port names will listen on for a directed pause. 

        value: str
        """
        self._properties['directed_address'] = value

    @property
    def choice(self):
        """choice getter

        The type of priority flow control.

        Returns: Union[ieee_802_1qbb, ieee_802_3x, choice, choice, choice, choice]
        """
        return self._properties['choice']

    @choice.setter
    def choice(self, value):
        """choice setter

        The type of priority flow control.

        value: Union[ieee_802_1qbb, ieee_802_3x, choice, choice, choice, choice]
        """
        self._properties['choice'] = value



from .snappicommon import SnappiObject


class FlowIpv4Dscp(SnappiObject):
    _TYPES = {
        'phb': '.flowpattern.FlowPattern',
        'ecn': '.flowpattern.FlowPattern',
    }

    def __init__(self):
        super(FlowIpv4Dscp, self).__init__()

    @property
    def phb(self):
        """phb getter

        A container for packet header field patterns.phb (per-hop-behavior) value is 6 bits: >=0 PHB <=63.

        Returns: obj(snappi.FlowPattern)
        """
        from .flowpattern import FlowPattern
        if 'phb' not in self._properties or self._properties['phb'] is None:
            self._properties['phb'] = FlowPattern()
        return self._properties['phb']

    @property
    def ecn(self):
        """ecn getter

        A container for packet header field patterns.ecn (explicit-congestion-notification) value is 2 bits: >=0 ecn <=3

        Returns: obj(snappi.FlowPattern)
        """
        from .flowpattern import FlowPattern
        if 'ecn' not in self._properties or self._properties['ecn'] is None:
            self._properties['ecn'] = FlowPattern()
        return self._properties['ecn']



from .snappicommon import SnappiList


class PortList(SnappiList):
    def __init__(self):
        super(PortList, self).__init__()


    def port(self, name=None, location=None):
        from .port import Port
        item = Port(name, location)
        self._add(item)
        return self



from .snappicommon import SnappiObject


class FlowTxRx(SnappiObject):
    _TYPES = {
        'port': '.flowport.FlowPort',
        'device': '.flowdevice.FlowDevice',
    }

    def __init__(self):
        super(FlowTxRx, self).__init__()

    @property
    def port(self):
        from .flowport import FlowPort
        if 'port' not in self._properties or self._properties['port'] is None:
            self._properties['port'] = FlowPort()
        self.choice = 'port'
        return self._properties['port']

    @property
    def device(self):
        from .flowdevice import FlowDevice
        if 'device' not in self._properties or self._properties['device'] is None:
            self._properties['device'] = FlowDevice()
        self.choice = 'device'
        return self._properties['device']

    @property
    def choice(self):
        """choice getter

        The type of transmit and receive container used by the flow.

        Returns: Union[port, device, choice, choice, choice]
        """
        return self._properties['choice']

    @choice.setter
    def choice(self, value):
        """choice setter

        The type of transmit and receive container used by the flow.

        value: Union[port, device, choice, choice, choice]
        """
        self._properties['choice'] = value



from .snappicommon import SnappiList


class FlowGtpExtensionList(SnappiList):
    def __init__(self):
        super(FlowGtpExtensionList, self).__init__()


    def flowgtpextension(self):
        from .flowgtpextension import FlowGtpExtension
        item = FlowGtpExtension()
        self._add(item)
        return self



import pytest


def test_port_metrics(api):
    """Get port metrics
    """
    request = api.port_metrics_request()
    port_metrics = api.get_port_metrics(request)
    print(port_metrics)


if __name__ == '__main__':
    pytest.main(['-vv', '-s', __file__])



from .snappicommon import SnappiList


class FlowStateList(SnappiList):
    def __init__(self):
        super(FlowStateList, self).__init__()


    def flowstate(self, name=None, transmit='None'):
        from .flowstate import FlowState
        item = FlowState(name, transmit)
        self._add(item)
        return self



import pytest
import json


@pytest.fixture(scope='session')
def api():
    """Demonstrates creating a top level Api instance.
    """
    import threading
    web_server_thread = threading.Thread(target=web_server)
    web_server_thread.setDaemon(True)
    web_server_thread.start()
    from ..api import Api
    yield Api()


@pytest.fixture(scope='function')
def b2b_config(api):
    """Demonstrates creating a back to back configuration of tx and rx 
    ports, devices and a single flow using those ports as endpoints for
    transmit and receive.
    """
    config = api.config()
    config.options.port_options.location_preemption = True
    
    tx_port, rx_port = config.ports \
        .port(name='Tx Port', location='10.36.74.26;02;13') \
        .port(name='Rx Port', location='10.36.74.26;02;14')

    tx_device, rx_device = config.devices \
        .device(name='Tx Devices', container_name=tx_port.name, device_count=1) \
        .device(name='Rx Devices', container_name=tx_port.name, device_count=1)
    tx_device.ipv4.name = 'Tx Ipv4'
    tx_device.ipv4.address.value = '1.1.1.1'
    tx_device.ipv4.gateway.value = '1.1.2.1'
    tx_device.ipv4.prefix.value = 16
    tx_device.ipv4.ethernet.mac.value = '00:00:01:00:00:01'

    flow = config.flows.flow(name='Tx -> Rx Flow')
    flow.tx_rx.port.tx_name = tx_port.name
    flow.tx_rx.port.rx_name = rx_port.name
    flow.size.fixed = 128
    flow.rate.pps = 1000
    flow.duration.fixed_packets.packets = 10000

    eth, vlan, ip, tcp = flow.packet.ethernet().vlan().ipv4().tcp()

    eth.src.value = '00:00:01:00:00:01'
    eth.dst.value_list = ['00:00:02:00:00:01', '00:00:02:00:00:01']
    eth.dst.result_group = 'eth dst mac'

    ip.src.increment.start = '1.1.1.1'
    ip.src.increment.step = '0.0.0.1'
    ip.src.increment.count = 10

    ip.dst.decrement.start = '1.1.2.200'
    ip.dst.decrement.step = '0.0.0.1'
    ip.dst.decrement.count = 10

    ip.priority.dscp.phb.value_list = [8, 16, 32]
    ip.priority.dscp.ecn.value = 1
    tcp.src_port.increment.start = '10'
    tcp.dst_port.increment.start = 1

    return config


from flask import Flask, request, Response, jsonify
app = Flask(__name__)
CONFIG = None


@app.route('/config', methods=['POST'])
def set_config():
    global CONFIG
    import snappi
    config = snappi.api.Api().config()
    config.deserialize(request.data.decode('utf-8'))
    test = config.options.port_options.location_preemption
    if test is not None and isinstance(test, bool) is False:
        return Response(status=590,
                        response=json.dumps({'detail': 'invalid data type'}),
                        headers={'Content-Type': 'application/json'})
    else:
        CONFIG = config
        return Response(status=200)


@app.route('/config', methods=['GET'])
def get_config():
    global CONFIG
    return Response(CONFIG.serialize(),
                    mimetype='application/json',
                    status=200)


@app.route('/results/port', methods=['POST'])
def get_port_metrics():
    import snappi
    api = snappi.api.Api()
    port_metrics_request = api.port_metrics_request()
    port_metrics_request.deserialize(request.data.decode('utf-8'))
    port_metrics = api.port_metrics()
    port_metrics.portmetric().portmetric()
    return Response(port_metrics.serialize(),
                    mimetype='application/json',
                    status=200)


@app.after_request
def after_request(resp):
    print(request.method, request.url, ' -> ', resp.status)
    return resp


def web_server():
    app.run(port=80, debug=True, use_reloader=False)



from .snappicommon import SnappiList


class LagList(SnappiList):
    def __init__(self):
        super(LagList, self).__init__()


    def lag(self, name=None, port_names=None):
        from .lag import Lag
        item = Lag(name, port_names)
        self._add(item)
        return self



from .snappicommon import SnappiList


class FlowHeaderList(SnappiList):
    def __init__(self):
        super(FlowHeaderList, self).__init__()


    def flowheader(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        self._add(item)
        return self

    def custom(self, bytes=None):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.custom
        self._add(item)
        return self

    def ethernet(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.ethernet
        self._add(item)
        return self

    def vlan(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.vlan
        self._add(item)
        return self

    def vxlan(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.vxlan
        self._add(item)
        return self

    def ipv4(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.ipv4
        self._add(item)
        return self

    def ipv6(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.ipv6
        self._add(item)
        return self

    def pfcpause(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.pfcpause
        self._add(item)
        return self

    def ethernetpause(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.ethernetpause
        self._add(item)
        return self

    def tcp(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.tcp
        self._add(item)
        return self

    def udp(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.udp
        self._add(item)
        return self

    def gre(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.gre
        self._add(item)
        return self

    def gtpv1(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.gtpv1
        self._add(item)
        return self

    def gtpv2(self):
        from .flowheader import FlowHeader
        item = FlowHeader()
        item.gtpv2
        self._add(item)
        return self



import pytest


def test_e2e_port_flow_config():
    """Get port metrics
    """
    import snappi

    api = snappi.api.Api()

    config = api.config()

    tx_port, rx_port = config.ports \
        .port(name='Tx Port', location='10.36.74.26;02;13') \
        .port(name='Rx Port', location='10.36.74.26;02;14')

    flow = config.flows.flow(name='Tx -> Rx Flow')
    flow.tx_rx.port.tx_name = tx_port.name
    flow.tx_rx.port.rx_name = rx_port.name
    flow.size.fixed = 128
    flow.rate.pps = 1000
    flow.duration.fixed_packets.packets = 10000

    eth, vlan, ip, tcp = flow.packet.ethernet().vlan().ipv4().tcp()

    eth.src.value = '00:00:01:00:00:01'
    eth.dst.value_list = ['00:00:02:00:00:01', '00:00:02:00:00:01']
    eth.dst.result_group = 'eth dst mac'

    ip.src.increment.start = '1.1.1.1'
    ip.src.increment.step = '0.0.0.1'
    ip.src.increment.count = 10

    ip.dst.decrement.start = '1.1.2.200'
    ip.dst.decrement.step = '0.0.0.1'
    ip.dst.decrement.count = 10

    ip.priority.dscp.phb.value_list = [8, 16, 32]
    ip.priority.dscp.ecn.value = 1
    tcp.src_port.increment.start = '10'
    tcp.dst_port.increment.start = 1

    print(config)


if __name__ == '__main__':
    pytest.main(['-vv', '-s', __file__])



from .snappicommon import SnappiObject


class FlowHeader(SnappiObject):
    _TYPES = {
        'custom': '.flowcustom.FlowCustom',
        'ethernet': '.flowethernet.FlowEthernet',
        'vlan': '.flowvlan.FlowVlan',
        'vxlan': '.flowvxlan.FlowVxlan',
        'ipv4': '.flowipv4.FlowIpv4',
        'ipv6': '.flowipv6.FlowIpv6',
        'pfcpause': '.flowpfcpause.FlowPfcPause',
        'ethernetpause': '.flowethernetpause.FlowEthernetPause',
        'tcp': '.flowtcp.FlowTcp',
        'udp': '.flowudp.FlowUdp',
        'gre': '.flowgre.FlowGre',
        'gtpv1': '.flowgtpv1.FlowGtpv1',
        'gtpv2': '.flowgtpv2.FlowGtpv2',
    }

    def __init__(self):
        super(FlowHeader, self).__init__()

    @property
    def custom(self):
        from .flowcustom import FlowCustom
        if 'custom' not in self._properties or self._properties['custom'] is None:
            self._properties['custom'] = FlowCustom()
        self.choice = 'custom'
        return self._properties['custom']

    @property
    def ethernet(self):
        from .flowethernet import FlowEthernet
        if 'ethernet' not in self._properties or self._properties['ethernet'] is None:
            self._properties['ethernet'] = FlowEthernet()
        self.choice = 'ethernet'
        return self._properties['ethernet']

    @property
    def vlan(self):
        from .flowvlan import FlowVlan
        if 'vlan' not in self._properties or self._properties['vlan'] is None:
            self._properties['vlan'] = FlowVlan()
        self.choice = 'vlan'
        return self._properties['vlan']

    @property
    def vxlan(self):
        from .flowvxlan import FlowVxlan
        if 'vxlan' not in self._properties or self._properties['vxlan'] is None:
            self._properties['vxlan'] = FlowVxlan()
        self.choice = 'vxlan'
        return self._properties['vxlan']

    @property
    def ipv4(self):
        from .flowipv4 import FlowIpv4
        if 'ipv4' not in self._properties or self._properties['ipv4'] is None:
            self._properties['ipv4'] = FlowIpv4()
        self.choice = 'ipv4'
        return self._properties['ipv4']

    @property
    def ipv6(self):
        from .flowipv6 import FlowIpv6
        if 'ipv6' not in self._properties or self._properties['ipv6'] is None:
            self._properties['ipv6'] = FlowIpv6()
        self.choice = 'ipv6'
        return self._properties['ipv6']

    @property
    def pfcpause(self):
        from .flowpfcpause import FlowPfcPause
        if 'pfcpause' not in self._properties or self._properties['pfcpause'] is None:
            self._properties['pfcpause'] = FlowPfcPause()
        self.choice = 'pfcpause'
        return self._properties['pfcpause']

    @property
    def ethernetpause(self):
        from .flowethernetpause import FlowEthernetPause
        if 'ethernetpause' not in self._properties or self._properties['ethernetpause'] is None:
            self._properties['ethernetpause'] = FlowEthernetPause()
        self.choice = 'ethernetpause'
        return self._properties['ethernetpause']

    @property
    def tcp(self):
        from .flowtcp import FlowTcp
        if 'tcp' not in self._properties or self._properties['tcp'] is None:
            self._properties['tcp'] = FlowTcp()
        self.choice = 'tcp'
        return self._properties['tcp']

    @property
    def udp(self):
        from .flowudp import FlowUdp
        if 'udp' not in self._properties or self._properties['udp'] is None:
            self._properties['udp'] = FlowUdp()
        self.choice = 'udp'
        return self._properties['udp']

    @property
    def gre(self):
        from .flowgre import FlowGre
        if 'gre' not in self._properties or self._properties['gre'] is None:
            self._properties['gre'] = FlowGre()
        self.choice = 'gre'
        return self._properties['gre']

    @property
    def gtpv1(self):
        from .flowgtpv1 import FlowGtpv1
        if 'gtpv1' not in self._properties or self._properties['gtpv1'] is None:
            self._properties['gtpv1'] = FlowGtpv1()
        self.choice = 'gtpv1'
        return self._properties['gtpv1']

    @property
    def gtpv2(self):
        from .flowgtpv2 import FlowGtpv2
        if 'gtpv2' not in self._properties or self._properties['gtpv2'] is None:
            self._properties['gtpv2'] = FlowGtpv2()
        self.choice = 'gtpv2'
        return self._properties['gtpv2']

    @property
    def choice(self):
        """choice getter

        TBD

        Returns: Union[custom, ethernet, vlan, vxlan, ipv4, ipv6, pfcpause, ethernetpause, tcp, udp, gre, gtpv1, gtpv2, choice, choice, choice]
        """
        return self._properties['choice']

    @choice.setter
    def choice(self, value):
        """choice setter

        TBD

        value: Union[custom, ethernet, vlan, vxlan, ipv4, ipv6, pfcpause, ethernetpause, tcp, udp, gre, gtpv1, gtpv2, choice, choice, choice]
        """
        self._properties['choice'] = value



from .snappicommon import SnappiList


class DeviceVlanList(SnappiList):
    def __init__(self):
        super(DeviceVlanList, self).__init__()


    def devicevlan(self, name=None):
        from .devicevlan import DeviceVlan
        item = DeviceVlan(name)
        self._add(item)
        return self



from .snappicommon import SnappiList


class DeviceList(SnappiList):
    def __init__(self):
        super(DeviceList, self).__init__()


    def device(self, name=None, container_name=None, device_count=1):
        from .device import Device
        item = Device(name, container_name, device_count)
        self._add(item)
        return self

    def ethernet(self, name=None):
        from .device import Device
        item = Device()
        item.ethernet
        self._add(item)
        return self

    def ipv4(self, name=None):
        from .device import Device
        item = Device()
        item.ipv4
        self._add(item)
        return self

    def ipv6(self, name=None):
        from .device import Device
        item = Device()
        item.ipv6
        self._add(item)
        return self

    def bgpv4(self, name=None, as_type='None'):
        from .device import Device
        item = Device()
        item.bgpv4
        self._add(item)
        return self



from .snappicommon import SnappiList


class Layer1List(SnappiList):
    def __init__(self):
        super(Layer1List, self).__init__()


    def layer1(self, name=None, port_names=None, speed='speed_10_gbps', media='None', promiscuous=False, mtu=1500, ieee_media_defaults=True, auto_negotiate=True):
        from .layer1 import Layer1
        item = Layer1(name, port_names, speed, media, promiscuous, mtu, ieee_media_defaults, auto_negotiate)
        self._add(item)
        return self



from .snappicommon import SnappiObject


class FlowPattern(SnappiObject):
    _TYPES = {
        'increment': '.flowcounter.FlowCounter',
        'decrement': '.flowcounter.FlowCounter',
    }

    def __init__(self, result_group=None):
        super(FlowPattern, self).__init__()
        self.result_group = result_group

    @property
    def increment(self):
        from .flowcounter import FlowCounter
        if 'increment' not in self._properties or self._properties['increment'] is None:
            self._properties['increment'] = FlowCounter()
        self.choice = 'increment'
        return self._properties['increment']

    @property
    def decrement(self):
        from .flowcounter import FlowCounter
        if 'decrement' not in self._properties or self._properties['decrement'] is None:
            self._properties['decrement'] = FlowCounter()
        self.choice = 'decrement'
        return self._properties['decrement']

    @property
    def choice(self):
        """choice getter

        TBD

        Returns: Union[value, value_list, increment, decrement, choice, choice, choice]
        """
        return self._properties['choice']

    @choice.setter
    def choice(self, value):
        """choice setter

        TBD

        value: Union[value, value_list, increment, decrement, choice, choice, choice]
        """
        self._properties['choice'] = value

    @property
    def value(self):
        """value getter

        TBD

        Returns: Union[string,number]
        """
        return self._properties['value']

    @value.setter
    def value(self, value):
        """value setter

        TBD

        value: Union[string,number]
        """
        self._properties['choice'] = 'value'
        self._properties['value'] = value

    @property
    def value_list(self):
        """value_list getter

        TBD

        Returns: list[Union[string,number]]
        """
        return self._properties['value_list']

    @value_list.setter
    def value_list(self, value):
        """value_list setter

        TBD

        value: list[Union[string,number]]
        """
        self._properties['choice'] = 'value_list'
        self._properties['value_list'] = value

    @property
    def result_group(self):
        """result_group getter

        A unique name is used to indicate to the system that the field may extend the result row key and create an aggregate result row for every unique value. To have result group columns appear in the flow result rows the flow result request allows for the result_group value to be specified as part of the request.

        Returns: str
        """
        return self._properties['result_group']

    @result_group.setter
    def result_group(self, value):
        """result_group setter

        A unique name is used to indicate to the system that the field may extend the result row key and create an aggregate result row for every unique value. To have result group columns appear in the flow result rows the flow result request allows for the result_group value to be specified as part of the request.

        value: str
        """
        self._properties['result_group'] = value



from .snappicommon import SnappiObject


class DeviceVlan(SnappiObject):
    _TYPES = {
        'tpid': '.devicepattern.DevicePattern',
        'priority': '.devicepattern.DevicePattern',
        'id': '.devicepattern.DevicePattern',
    }

    def __init__(self, name=None):
        super(DeviceVlan, self).__init__()
        self.name = name

    @property
    def name(self):
        """name getter

        Unique system wide name of an object that is also the primary key for objects found in arrays.

        Returns: str
        """
        return self._properties['name']

    @name.setter
    def name(self, value):
        """name setter

        Unique system wide name of an object that is also the primary key for objects found in arrays.

        value: str
        """
        self._properties['name'] = value

    @property
    def tpid(self):
        """tpid getter

        Vlan tag protocol identifier.

        Returns: obj(snappi.DevicePattern)
        """
        from .devicepattern import DevicePattern
        if 'tpid' not in self._properties or self._properties['tpid'] is None:
            self._properties['tpid'] = DevicePattern()
        return self._properties['tpid']

    @property
    def priority(self):
        """priority getter

        Vlan priority.

        Returns: obj(snappi.DevicePattern)
        """
        from .devicepattern import DevicePattern
        if 'priority' not in self._properties or self._properties['priority'] is None:
            self._properties['priority'] = DevicePattern()
        return self._properties['priority']

    @property
    def id(self):
        """id getter

        Vlan id.

        Returns: obj(snappi.DevicePattern)
        """
        from .devicepattern import DevicePattern
        if 'id' not in self._properties or self._properties['id'] is None:
            self._properties['id'] = DevicePattern()
        return self._properties['id']
